@@ -1,5 +1,5 @@
 package Net::Amazon::S3;
-$Net::Amazon::S3::VERSION = '0.87';
+$Net::Amazon::S3::VERSION = '0.88';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 
@@ -340,8 +340,9 @@ sub delete_key {
 sub _validate_acl_short {
     my ( $self, $policy_name ) = @_;
 
+    # Current list at https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#canned-acl
     if (!grep( { $policy_name eq $_ }
-            qw(private public-read public-read-write authenticated-read) ) )
+            qw(private public-read public-read-write aws-exec-read authenticated-read bucket-owner-read bucket-owner-full-control log-delivery-write ) ) )
     {
         croak "$policy_name is not a supported canned access policy";
     }
@@ -456,7 +457,7 @@ Net::Amazon::S3 - Use the Amazon S3 - Simple Storage Service
 
 =head1 VERSION
 
-version 0.87
+version 0.88
 
 =head1 SYNOPSIS
 
@@ -908,7 +909,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
