@@ -1,12 +1,19 @@
 package Net::Amazon::S3::Role::Bucket;
 # ABSTRACT: Bucket role
-$Net::Amazon::S3::Role::Bucket::VERSION = '0.87';
+$Net::Amazon::S3::Role::Bucket::VERSION = '0.88';
 use Moose::Role;
 use Scalar::Util;
 
 around BUILDARGS => sub {
     my ($orig, $class, %params) = @_;
 
+    $params{region} = $params{bucket}->region
+        if $params{bucket}
+        and Scalar::Util::blessed( $params{bucket} )
+        and ! $params{region}
+        and $params{bucket}->has_region
+        ;
+
     $params{bucket} = $params{bucket}->name
         if $params{bucket}
         and Scalar::Util::blessed( $params{bucket} )
@@ -16,8 +23,11 @@ around BUILDARGS => sub {
     $params{bucket} = Net::Amazon::S3::Bucket->new(
         bucket => $params{bucket},
         account => $params{s3},
+        (region => $params{region}) x!! $params{region},
     ) if $params{bucket} and ! ref $params{bucket};
 
+    delete $params{region};
+
     $class->$orig( %params );
 };
 
@@ -41,7 +51,7 @@ Net::Amazon::S3::Role::Bucket - Bucket role
 
 =head1 VERSION
 
-version 0.87
+version 0.88
 
 =head1 AUTHOR
 
@@ -49,7 +59,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
